// iambic_toplevel.v

/*

IambicV: Iambic keyer in Verilog
Copyright  2011 Stephen C. Trier

This file is part of IambicV

IambicV is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

IambicV is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with IambicV.  If not, see <http://www.gnu.org/licenses/>.

*/

// Iambic Keyer
// Stephen Trier KG8IH
// http://skywired.net/
// sct (at) skywired.net


`define SPEED 8'd120    // With 1000 Hz clk, this is 10 WPM.

`define MODEB 1'd1



// Pin list:

//   rst_n      input   Active-low reset

//   clk        input   1 kHz clock.

//   dit        input   Dit paddle. Active low.

//   dah        input   Dah paddle. Active low.

//   key        output  Keying line. Active high.

//   sidetone   output  Sidetone. Square wave, 500 Hz.



module iambic_toplevel(input rst_n, input clk, input dit, input dah, output key, output sidetone);

    reg tone;

    iambic keyer(rst_n, clk, `SPEED, `MODEB, !dit, !dah, key);


    // Cheap and dirty sidetone
    always @(posedge clk) tone = !tone;
    assign sidetone = key && tone;

endmodule
